flutter_dubov_system_native

The native implementation of flutter_dubov_system.

This package provides the native desktop (Windows, macOS, Linux) and mobile (Android, iOS) platform support for the flutter_dubov_system plugin using Dart FFI to interface directly with the FIDE-approved CPPDubovSystem C++ engine.

Usage

This package is not meant to be used directly. It is an endorsed implementation package for flutter_dubov_system.

If you want to use the Dubov pairing system in your Flutter app, please depend on the main package:

dependencies:
  flutter_dubov_system: ^0.0.1

For documentation, usage examples, and more information, please refer to the flutter_dubov_system main package